# witcher
Witcher is an automated, driverless tool to build an errorfree machine learning application.


Witcher is an automated AI application designed to speed up the data processing phases.
The current witcher's magical-recommender-system will provide you with a comprehensive product recommendation using product popularity, product similarity and user similarity models.
 
Magical data processing, predictive, and deep learning models will be joining witchers functions very soon :)

hope you will enjoy using the witcher library

Thank you. 

Babak.EA


How to run : 

<b> using Jupyter notbook </b> 

from witcher import Recommender






source code : github
https://github.com/BabakEA/witcher




PyPi : 
pip install witcher 
